@@ -1,4 +1,8 @@
 class Replay(object):
+    """
+    Class for replay events
+    """
+
     event_type = 18
 
     @property
@@ -15,4 +19,7 @@ class Replay(object):
 
     @property
     def event_stats(self):
+        """
+        returns list of dicts with all stats for event
+        """
         return self.base_stats
